# PermitDurationChallengeNonAcceptanceResponseRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_user_identifier** | **str** | Max length 100 characters | [optional] 
**internal_user_name** | **str** | Max length 100 characters | [optional] 
**non_acceptance_response_status** | [**DurationChallengeNonAcceptanceResponseStatus**](DurationChallengeNonAcceptanceResponseStatus.md) |  | 
**new_reasonable_period_end_date** | **datetime** | Required if non_acceptance_response_status &#x3D; reasonable_period_end_date_changed | [optional] 
**non_acceptance_response_details** | **str** | Max length 500 characters | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

